# SPDX-FileCopyrightText: 2023-present Wytamma Wirth <wytamma.wirth@me.com>
#
# SPDX-License-Identifier: MIT
import sys

if __name__ == "__main__":
    from pipeline_name.cli import pipeline_name

    sys.exit(pipeline_name())
